import os
import unittest
import ddt
from pages.activityCreate64Page import ActivityCreate64
from aceui.lib.core import (
    select_Browser_WebDriver,
    reply_case_fail,
    get_data,
    join_url
)
from aceui.lib import (
    gl,
    HTMLTESTRunnerCN
)

@ddt.ddt
class TestActivityCreate64(unittest.TestCase):
    """营销－开卡关怀"""
    @classmethod
    def setUpClass(cls):
        cls.driver = select_Browser_WebDriver()
        cls.url = join_url('/activity/create/64')

    @classmethod
    def tearDownClass(cls):
        cls.driver.quit()
        # pass


    @ddt.data(*get_data('activityCreate64', 'CASE1'))
    @reply_case_fail(num=3)
    def testCase1(self, data):
        """开卡关怀"""
        print('========★{}★========'.format(data['case_desc'])) #case描述
        self.tc = ActivityCreate64(
            self.url,
            self.driver,
            data['page_title']
        )
        self.tc.open
        #活动名称
        self.tc.input_activity_name(data['activity_name'])
        #赠券设置-增加券
        self.tc.click_add_coupon()
        #券类型;0代金券；1礼品券
        self.tc.click_coupon_type(data['coupon_type'])
        #使用
        self.tc.click_coupon_used(data['coupon_index'])
        #赠送积分
        self.tc.input_credit(data['credit_num'])
        #赠送储值
        self.tc.input_charge(data['charge_num'])
        #发券提醒;0不提醒；1短信提醒
        self.tc.click_send_remind(data['remind_index'])
        #券到期提醒;0不提醒；1短信提醒
        self.tc.click_expire(data['expire_index'])
        #活动卡类别
        self.tc.click_card_type()
        #活动开始时间－结束时间
        self.tc.input_start_time(data['start_time'])
        self.tc.input_end_time(data['end_time'])
        #保存-确认
        self.tc.click_save_button()
        self.tc.click_sconfirm_btn()
        #输入活动名称
        self.tc.input_search_name(data['activity_name'])
        #查询
        self.tc.click_search_button()
        #断言
        self.tc.assert_add_success(data['start_time'])
        #删除
        self.tc.click_delete_button()
        #断言列表为空
        self.assertTrue(self.tc.assert_delete_result())



if __name__ == "__main__":
    suite = unittest.TestSuite()
    tests = [
        unittest.TestLoader().loadTestsFromTestCase(
            TestActivityCreate64
        )
    ]

    suite.addTests(tests)
    filePath = os.path.join(gl.reportPath, 'Report.html')  # 确定生成报告的路径
    print(filePath)

    with open(filePath, 'wb') as fp:
        runner = HTMLTESTRunnerCN.HTMLTestRunner(
            stream=fp,
            title=u'UI自动化测试报告',
            description=u'详细测试用例结果',  # 不传默认为空
            tester=u"yhleng"  # 测试人员名字，不传默认为小强
        )
        # 运行测试用例
        runner.run(suite)



from selenium.webdriver.common.by import By
from aceui.base.basepage import BasePage

class ActivityCreate64(BasePage):
    """营销－开卡关怀"""
    #>>>>>>>>>>>>>>定位<<<<<<<<<<<<<<<<<
    #活动名称
    activity_name_loc = (By.ID, "inputName")
    #赠券设置
    activity_set_loc = (By.ID, "dropdownCoupon")
    #券类型选择
    activity_coupon_type = ['代金券', '礼品券']
    #使用券;0第一个券，1第二个，依此类推
    activity_used_locs = (By.XPATH, "//a[contains(text(),'使用')]")
    #使用券张数
    activity_usednum_loc = (By.NAME, "couponCount[]")
    #发券提醒;0不提醒；1短信提醒
    activity_send_locs = (By.XPATH, "//input[@name='sendRemind']/..")
    #券到期提醒;0不提醒；1短信提醒
    activity_expire_locs = (By.XPATH, "//input[@name='expireRemind']/..")
    #赠送积分
    activity_credit_loc = (By.NAME, "creditNum")
    #赠送储值
    activity_charge_loc = (By.NAME, "chargeNum")
    #活动类别-更改链接
    activity_atype_loc = (By.XPATH, "//input[@name='ccids']/../button[1]")
    #活动类别－确定
    activity_confirm_loc = (By.XPATH, "//button[contains(text(),'确定')]")
    #活动开始时间
    activity_stime_loc = (By.ID, "inputStartDate")
    #活动结束时间
    activity_etime_loc = (By.ID, "inputEndDate")
    #保存
    activity_save_loc = (By.XPATH, "//button[contains(text(),'保存')]")
    activity_sconfirm_loc = (By.XPATH, "//button[contains(text(),'确认')]")
    #删除
    activity_delete_loc = (By.LINK_TEXT, "删除")
    #断言
    activity_assert_loc = (
        By.CSS_SELECTOR,
        "div.we-table-responsive > table:nth-child(1) > tbody > tr:nth-child(1) > td:nth-child(1)"
    )
    #活动名称
    coupon_acName_loc = (By.ID, "inputActivityName")
    #查询
    coupon_search_loc = (By.XPATH, "//button[contains(text(),'查询')]")
    #活动列表为空时.显示无查询结果
    assert_del_loc = (By.XPATH, "//span[contains(text(),'无查询结果')]")
    #########################页面操作###################
    def assert_delete_result(self):
        """断言删除结果"""
        rs = self.is_exist(*(self.assert_del_loc))
        return rs

    def input_search_name(self, text):
        """输入活动名称,以备查询"""
        self.input_text(
            text,
            '活动名称',
            *(self.coupon_acName_loc)
        )

    def click_search_button(self):
        """单击查询按钮"""
        self.click_button(
            '查询',
            *(self.coupon_search_loc)
        )

    def input_activity_name(self, text):
        """输入活动名称"""
        self.input_text(
            text,
            '活动名称',
            *(self.activity_name_loc)
        )

    def click_add_coupon(self):
        """赠券设置，添加券按钮"""
        self.click_button(
            '添加券',
            *(self.activity_set_loc)
        )

    def click_coupon_type(self, index):
        """选择券类型；0代金券；1礼品券"""
        index = int(index)
        self.click_button(
            self.activity_coupon_type[index],
            *(By.LINK_TEXT, self.activity_coupon_type[index])
        )

    def click_coupon_used(self, index):
        """使用券；0第一张券；1第二张，依此类推"""
        self.click_btn_index(
            '使用',
            index,
            *(self.activity_used_locs)
        )

    def click_send_remind(self, index):
        """发券提醒；0不提醒；1短信提醒"""
        self.click_btn_index(
            '发券提醒',
            index,
            *(self.activity_send_locs)
        )

    def click_expire(self, index):
        """到期提醒;0不提醒；1短信提醒"""
        self.click_btn_index(
            '到期提醒',
            index,
            *(self.activity_expire_locs)
        )

    def input_credit(self, text):
        """赠送积分"""
        self.input_text(
            text,
            '赠送积分',
            *(self.activity_credit_loc)
        )


    def input_charge(self, text):
        """赠送储值"""
        self.input_text(
            text,
            '赠送储值',
            *(self.activity_charge_loc)
        )


    def input_start_time(self, text):
        """活动开始时间"""
        self.clear_input_text(
            *(self.activity_stime_loc)
        )
        self.input_text(
            text,
            '活动开始时间',
            *(self.activity_stime_loc)
        )

    def input_end_time(self, text):
        """活动结束时间"""
        self.clear_input_text(
            *(self.activity_etime_loc)
        )
        self.input_text(
            text,
            '活动结束时间',
            *(self.activity_etime_loc)
        )

    def click_save_button(self):
        """保存"""
        self.click_button(
            '保存',
            *(self.activity_save_loc)
        )

    def click_sconfirm_btn(self):
        """保存确认按钮"""
        self.click_button(
            '确认',
            *(self.activity_sconfirm_loc)
        )

    def click_card_type(self):
        """活动卡类别"""
        self.click_button(
            '活动卡类别',
            *(self.activity_atype_loc)
        )
        self.click_button(
            '确定',
            *(self.activity_confirm_loc)
        )

    def click_delete_button(self):
        """删除"""
        self.click_button(
            '删除',
            *(self.activity_delete_loc)
        )
        self.click_button(
            '确认',
            *(self.activity_sconfirm_loc)
        )
        self.wait(5000)

    def assert_add_success(self, text):
        """断言新增开卡关怀活动成功"""
        txt = self.get_tag_text(
            'text',
            *(self.activity_assert_loc)
        )

        # 截取断言图片，会展示在报告中
        self.get_image
        if str(txt).strip() != str(text).strip():
            return False
        return True




"""
create:2018/10/23
by:yhleng
"""
import time
import os
import string
import random
import zipfile
import shutil
import csv
from selenium import webdriver
import yaml
from aceui.lib import gl
from aceui.lib.config import CONF


def select_Browser_WebDriver():
    """
    根据config.yaml配置文件，来选择启动的浏览器
    :return:
    """
    #读取config.yam配置文件中，浏览器配置
    bro_name = CONF.read(gl.configFile)['CONFIG']['Browser']

    #根据borName决定，启动，哪个浏览器
    if str(bro_name).strip().lower() == 'chrome':
        driver = webdriver.Chrome()
    elif str(bro_name).strip().lower() == 'firefox':
        driver = webdriver.Firefox()
    else:
        driver = webdriver.Ie()
    return driver



def write_ymal(path, data):
    """
    写YAML文件内容
    :param path: YAML文件路径
    :param data: 写入的数据
    :return: 无
    """
    with open(path, 'wb') as fp:
        yaml.dump(data, fp)


def get_yaml_field(path):
    """
    读取YAML内容
    :param path: xxxx.YAML文件所在路径
    :return: 指定节点内容
    """
    with open(path, 'rb') as fp:
        cont = fp.read()

    ret = yaml.load(cont, Loader=yaml.FullLoader)
    return ret


def get_run_flag(scenario_key, casename):
    """
    获取运行标记，来决定是否执行
    :param scenario_key:
    :return: Y 或 N
    """
    conf = CONF.read(gl.configFile)
    return conf['RUNING'][scenario_key]['Flag'][casename]['Flag']



def cook_info(func):
    """
    从配置文件获取cookies信息
    :param func: 函数名
    :return: 函数
    """
    def warpper(*args, **kwargs):
        cook1= CONF.read(gl.configFile)['CONFIG']['Cookies']['LoginCookies']
        return func(cook=cook1, *args, **kwargs)
    return warpper


def replay(func):
    """
    回放速度
    :param func: 函数名
    :return: wrapper
    """
    def wrapper(*args, **kwargs):
        func(*args, **kwargs)
        sleeptime = float(CONF.read(gl.configFile)['RUNING']['REPLAY']['Time']) / 1000
        time.sleep(sleeptime)
        return func
    return wrapper



def hight_light_conf(key):
    """
    配置元素，是否高亮显示
    :param key: config.yaml 中关键字 HightLight:1 高亮 其它忽略
    :return:
    """
    def _wrapper(func):
        def wrapper(*args, **kwargs):
            ret = None
            if CONF.read(gl.configFile)[key] == 1:
                ret = func(*args, **kwargs)
            return ret
        return wrapper
    return _wrapper



def remove_all_files(dirpath):
    """
    删除目标,目录下文件及文件夹
    :param dirpath: 目标目录
    :return: 无
    """
    if os.path.exists(dirpath):
        shutil.rmtree(dirpath)

def zip_dir(dirpath,out_fullName):
    """
    压缩指定文件夹
    :param dirpath: 目标文件夹路径
    :param outFullName: 压缩文件保存路径+xxxx.zip
    :return: 无
    """
    zip = zipfile.ZipFile(out_fullName, "w", zipfile.ZIP_DEFLATED)
    for path, dirnames, filenames in os.walk(dirpath):
        # 去掉目标跟路径，只对目标文件夹下边的文件及文件夹进行压缩
        fpath = path.replace(dirpath, '')

        for filename in filenames:
            zip.write(
                os.path.join(path, filename),
                os.path.join(fpath, filename)
            )
    zip.close()


def reply_case_fail(num=3):
    """
    测试case失败后，重新执行功能
    :param num: 失败最多可以执行次数，默认为3次
    :return: fun本身或者抛出异常
    """
    def _warpper(func):
        def warpper(*args, **kwargs):
            raise_info = None
            rnum = 0
            num = CONF.read(gl.configFile)['RUNING']['CASE']['Retry']
            for _ in range(num):
                try:
                    ret = func(*args, **kwargs)
                    if rnum > 1:
                        print('重试{}次成功'.format(rnum))
                    return ret
                except Exception as ex:
                    rnum += 1
                    raise_info = ex
            print('重试{}次,全部失败'.format(rnum))
            raise raise_info
        return warpper
    return _warpper


def get_data(file, field):
    """
    从data目录下的yaml文件读取指定字段(field)CASE数据
    :param file:yaml数据文件
    :param field: 指定字段读取
    :return: 结构数据
    """
    yaml = (str(file).endswith('.yaml'), str(file).endswith('.yam'))
    file = '{}.yaml'.format(file) if not (yaml[0] or yaml[1]) else file
        

    field = str(field).strip().upper()
    data = CONF.read(
        os.path.join(
            gl.dataPath, file
        )
    )[field]
    return data


def create_dir(path):
    """
    如果文件夹不存在，则创建
    :param path:
    :return:
    """
    folder = os.path.exists(path)
    if not folder:
        os.makedirs(path)


def genrandomstr(lenstr=5):
    """
    随机产生数据
    :param lenstr: 需要字符串的长度,
    :return: 指定长度的字符和数字组合的字符串，例如：lenstr=5，"Qamo8"
    """
    strs = "".join(random.choice(string.ascii_letters + string.digits)
                   for _ in range(lenstr)
                   )
    return strs


def rndint(min=0, max=1):
    """
    返回一个随机整数
    :param max:
    :param min:
    :return:
    """
    return random.randint(min, int(max))


def join_url(url):
    """
    读取config基本url并拼接完整
    :param url: 页面url
    :return: 完整url
    """
    base_url = CONF.read(gl.configFile)['CONFIG']['Base_Url']

    if not url.startswith('/'):
        url = "/{}".format(url)

    return "{}{}".format(base_url, url)


def autoi(strword):
    """
    将字符串类型的数字转换成int类型
    :param strword: 字符串数字，'1,989.00'
    :return: int类型 1989
    """
    if strword.count('0') != 0 or strword.count(',') != 0:
        strword = ''.join(
            strword.split('.')[0].split(',')
        )
    
    return int(strword)



def rnd_num(len=5):
    """
    返回一个随机整数
    :param max:
    :param min:
    :return:
    """
    rnd = ''
    for _ in range(len):
        rnd += str(random.randint(0, 9))

    return rnd



def createphone():
    """
    :return: 手机号
    """
    mobile_list = ['139', '138', '136', '133',
               '134', '156', '158', '155', '159'
               ]
    phone = '{}{}'.format(
        random.choice(mobile_list),
        ''.join(random.choice('0123456789') for _ in range(8))
    )

    return phone


def write_csvfile(filepath, header, data):
    """
    :param filepath:csv文件路径
    :param header:csv文件标头（表格第一行）[]
    :param data:写入数据，[{}]
    :return:无
    """
    with open(filepath, 'w', newline='') as files:
        writer = csv.DictWriter(files, header)
        writer.writeheader()
        writer.writerows(data)


def send_dding_msg(token, msg):
    '''
    推送消息到钉群
    '''
    import requests
    payload = {
        "msgtype": "text",
        "text": {
            "content": msg,
            # "mentioned_mobile_list":["13718651998"],
        }
    }
    headers = {
        'Content-Type': 'application/json'
    }
    d_url = 'https://qyapi.weixin.qq.com/cgi-bin/webhook/send?key={}'.format(token)

    res = requests.request('POST', d_url, headers=headers, json=payload)

    return res


if __name__ == "__main__":
    # stra = genrandomstr(20)
    # print(type(stra))
    # url = join_url('/activity/create/1024')
    print(createphone())





# ########################################################
import os
import sys
# 将根目录加入sys.path中,解决命令行找不到包的问题
curPath = os.path.abspath(os.path.dirname(__file__))
rootPath = os.path.split(curPath)[0]
sys.path.insert(0, rootPath)
# ########################################################

import unittest
import time
from aceui.lib.config import CONF
from aceui.lib import HTMLTESTRunnerCN
from aceui.lib.emailstmp import EmailClass




if __name__=="__main__":
    cur_path = os.getcwd()

    case_path = os.path.join(cur_path, 'testCase')

    report_path = os.path.join(cur_path, 'reports')

    if not os.path.exists(report_path):
        os.makedirs(report_path)

    suite = unittest.TestSuite()

    suite.addTest(
        unittest.defaultTestLoader.discover(case_path, 'test*.py')
    )
    filePath = os.path.join(report_path, 'Report.html')  # 确定生成报告的路径
    print(filePath)

    with open(filePath, 'wb') as fp:
        runner = HTMLTESTRunnerCN.HTMLTestRunner(
            stream=fp,
            title=u'UI自动化测试报告',
            description=u'详细测试用例结果',  # 不传默认为空
            tester="天枢"  # 测试人员名字，不传默认为小强
        )

        # 运行测试用例
        runner.run(suite)

